==> sc2monitor-0.2.6.tar.gz: sc2monitor-0.2.6/README.md <==
[![](https://img.shields.io/pypi/v/sc2monitor.svg)](https://pypi.org/project/sc2monitor/)

# sc2monitor
Python (>=3.7.1) script that when executed regularly keeps track of medium amount StarCraft 2 accounts on the 1vs1 ladder

## Installation
Install this Python 3 package via `pip` by executing `pip install sc2monitor`

## Execution
To collect data run the following script regularly (every 5-15 minutes), e.g. via cronjob:
```python
import sc2monitor

sc2monitor.init(host='db-host',
                user='db-user',
                passwd='db-password',
                db='db-database',
                protocol='db-protocol',
                apikey='your-bnet-api-key',
                apisecret='your-bnet-api-secret')
sc2monitor.run()
```
Your API-key `your-bnet-api-key` and secret `your-bnet-api-secret` have to be created by registering an application at https://develop.battle.net/access/ and have to be passed only once or when you want to change them. If not specified `mysql+pymysql` will be used as database protocol - other protocol options can be found at https://docs.sqlalchemy.org/en/latest/dialects/.

If not executed reguarly the script will try to make an educated guess for games played since the last execution.

Execution protocol will automatically logged to the database.

You can add players to monitor either by passing their StarCraft 2 URL:
```python
sc2monitor.add_player('https://starcraft2.com/en-gb/profile/2/1/221986')
```

## Data
The collected data (including statistics) can be accessed via the database tables.

==> sc2monitor-0.2.9.tar.gz: sc2monitor-0.2.9/README.md <==
[![](https://img.shields.io/pypi/v/sc2monitor.svg)](https://pypi.org/project/sc2monitor/)

# sc2monitor
Python (>=3.7.1) script that when executed regularly keeps track of medium amount StarCraft 2 accounts on the 1vs1 ladder

## Installation
Install this Python 3 package via `pip` by executing `pip install sc2monitor`

## Execution
To collect data run the following script regularly (every 5-15 minutes), e.g. via cronjob:
```python
import sc2monitor

sc2monitor.init(host='db-host',
                user='db-user',
                passwd='db-password',
                db='db-database',
                protocol='db-protocol',
                apikey='your-bnet-api-key',
                apisecret='your-bnet-api-secret')
sc2monitor.run()
```
Your API-key `your-bnet-api-key` and secret `your-bnet-api-secret` have to be created by registering an application at https://develop.battle.net/access/ and have to be passed only once or when you want to change them. If not specified `mysql+pymysql` will be used as database protocol - other protocol options can be found at https://docs.sqlalchemy.org/en/latest/dialects/.

If not executed reguarly the script will try to make an educated guess for games played since the last execution.

At execution a protocol will automatically logged to the database.

You can add players to monitor either by passing their StarCraft 2 URL:
```python
sc2monitor.add_player('https://starcraft2.com/en-gb/profile/2/1/221986')
```

## Data
The collected data (including statistics) can be accessed via the database tables.
